// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.actions;

import com.intellij.openapi.project.Project;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.actionSystem.DataKeys;
//import com.intellij.openapi.actionSystem.DataConstants;
import com.telelogic.integration.intellij.cm.CMConfiguration;
import com.telelogic.integration.intellij.cm.CMUtil;
import com.telelogic.integration.intellij.cli.AddCommand;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.util.*;

/**
 * @author Luke Stahlman
 * Handles user actions for the add command.  This specifically handles pre-existing files/dirs in the project
 */
public class AddAction extends CMAction implements ActionListener {

    /**
     * Overrides the ActionListener default constructor
     */
    public AddAction() {
        super();
    }

    /**
     * Constructor used when adding this class as an ActionListener
     * @param p Project
     */
    public AddAction(Project p) {
        super();
        project = p;
        myConfig = CMConfiguration.getInstance(project);

    }

    /**
     * Action method called via a JComponent (eg JButton).
     * @param e Event
     */
    public void actionPerformed(ActionEvent e) {
        myConfig = CMConfiguration.getInstance(project);
        VirtualFile file = myConfig.getSelectedFile();
        //virtualFiles = VirtualFile.EMPTY_ARRAY;

        ArrayList<VirtualFile> fileArray = new ArrayList<VirtualFile>();
        fileArray.add(file);

        virtualFiles = fileArray.toArray(new VirtualFile[fileArray.size()]);

        if(validateAction()) {
            AddCommand.addMixed(project, virtualFiles, null);
        }
    }

    /**
     * Action method called via an IntelliJ popup menu.  These actions contain context data.
     * @param event Event
     */
    public void actionPerformed(AnActionEvent event) {
        project = (Project)event.getData(DataKeys.PROJECT);
        myConfig = CMConfiguration.getInstance(project);
        virtualFiles = CMUtil.getVirtualFiles( event );

        if(validateAction()) {
            AddCommand.addMixed(project, virtualFiles, null);
        }
    }

    /**
     * Overloads super method for additional validation
     * @return Whether the validation checks succeeded
     */
    private boolean validateAction() {
       return super.validateAction(myConfig, virtualFiles);
    }
}

