// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.actions;

import com.intellij.openapi.project.Project;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.actionSystem.DataKeys;
//import com.intellij.openapi.actionSystem.DataConstants;
import com.telelogic.integration.intellij.cm.CMConfiguration;
import com.telelogic.integration.intellij.cm.CMUtil;
import com.telelogic.integration.intellij.cli.Tasks;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.util.ArrayList;

/**
 * Handles user actions related to associating objects with a task
 * @author Luke Stahlman
 */
@SuppressWarnings({"ComponentNotRegistered"})
public class AssociateWithTask extends CMAction implements ActionListener {
    private VirtualFile[] virtualFiles;

    /**
     * Default constrcutor
     */
    public AssociateWithTask(){ super(); }

    /**
     * Constructor method used when setting this as an ActionListener
     * @param p The active project
     */
    public AssociateWithTask(Project p) {
        super();
        project = p;
    }

    /**
     * Handles JComponent actions.
     * This method assumes the action was fired for the file currently selected (in focus) in the IDEA editor. Event
     * data can't be used to find the project, config and files involved in this action. It relies instead on the
     * Project instance passed to the constructor to gather file information and validate the action. On successful
     * validation, the CLI command is executed via com.telelogic.integration.intellij.cm.Tasks.
     * @param event Event data (not used)
     */
    public void actionPerformed(ActionEvent event) {
        myConfig = CMConfiguration.getInstance(project);
        //status = CMPlugin.getInstance(project).toolWindow;
       VirtualFile file = myConfig.getSelectedFile();

        ArrayList<VirtualFile> fileArray = new ArrayList<VirtualFile>();
        fileArray.add(file);

        virtualFiles = fileArray.toArray(new VirtualFile[fileArray.size()]);


        if(validateAction()) {
            // run command
            Tasks.associateWithTask(myConfig.getDefaultTask(), virtualFiles, project);
        }
    }

    /**
     * Handles IDEA popup menu actions.
     * Project, config and file information is gathered from the event data.  On successful validation, the CLI command
     * is executed via com.telelogic.integration.intellij.cm.Tasks.
     * @param event Event data
     */
    public void actionPerformed(AnActionEvent event) {
        project = (Project)event.getData(DataKeys.PROJECT);
        myConfig = CMConfiguration.getInstance(project);
        //status = CMPlugin.getInstance(project).toolWindow;
        virtualFiles = CMUtil.getVirtualFiles( event );


        if(validateAction()) {
            // run command
            Tasks.associateWithTask(myConfig.getDefaultTask(), virtualFiles, project);
        }

    }

    /**
     * Overloads super method for additional validation
     * @return Whether the validation checks succeeded
     */
    private boolean validateAction() {
        return super.validateAction(myConfig, virtualFiles);
    }

}
