// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.actions;

import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.DataKeys;
import com.intellij.openapi.util.IconLoader;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.vcs.history.VcsFileRevision;
import com.intellij.openapi.vcs.history.FileHistoryPanel;
import com.intellij.openapi.vcs.VcsDataKeys;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.ui.dualView.DualView;
import com.telelogic.integration.intellij.cm.CMUtil;
import com.telelogic.integration.intellij.cm.CMMergeProvider;

import java.util.List;
import java.util.ArrayList;
import java.util.Arrays;
import java.awt.*;

public class MergeAction extends CMAction {

    public MergeAction() {
        super("Merge", "Merge two parallel files", IconLoader.findIcon("/com/telelogic/integration/intellij/ui/icons/merge_icon.gif"));
    }
   

    public void actionPerformed(AnActionEvent event) {
        project = (Project)event.getData(DataKeys.PROJECT);
        virtualFiles    = CMUtil.getVirtualFiles( event );
        ArrayList<VirtualFile> files = new ArrayList<VirtualFile>();
        files.addAll(Arrays.asList(virtualFiles));

        //final VcsFileRevision revision = event.getData(VcsDataKeys.VCS_FILE_REVISION);
        CMMergeProvider.doMerge(project, files);
    }

    public void update(AnActionEvent event) {
        //super.update(event);
        project = (Project)event.getData(DataKeys.PROJECT);

        if(project == null) {
            return;
        }
        Component view = event.getData(DataKeys.CONTEXT_COMPONENT);

        event.getPresentation().setEnabled(event.getData(VcsDataKeys.VCS_VIRTUAL_FILE) != null);
    }
}
