// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.actions;

import com.intellij.openapi.project.Project;
import com.telelogic.integration.intellij.cm.CMConfiguration;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

/**
 * Handles changes to selections in the options tab
 * @author Luke Stahlman
 */
public class OptionsTabAction implements ActionListener {

    private int  buttonGroup;
    private CMConfiguration config;

    public static final int CHECKOUT   = 1;
    public static final int ADD        = 2;
    public static final int TASK       = 3;

    /**
     * Constructor method
     * The button group integers may need to be referenced to the config tab itself.  It's probably not a good idea to
     * have the integers defined here.
     * @param g Button group
     * @param p Active project
     */
    public OptionsTabAction(int g, Project p) {
        buttonGroup = g;
        config = CMConfiguration.getInstance(p);
    }

    /**
     * Used to determine which option changed and then make the desired change to the plugin configuration.
     * @param event Event data
     */
    public void actionPerformed(ActionEvent event) {
        String command = event.getActionCommand();

        switch(buttonGroup) {
            case CHECKOUT:
                config.setOptionTabCheckout(command);
                break;
            case ADD:
                config.setOptionTabAdd(command);
                break;
            case TASK:
                config.setOptionTabTask(command);
                break;
            default:
                break;
        }
    }
}
