// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.actions;

import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.DataKeys;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.vcs.VcsException;
import com.intellij.openapi.ui.Messages;
import com.intellij.vcsUtil.VcsUtil;
import com.telelogic.integration.intellij.ui.dialogs.ParallelsDialog;
import com.telelogic.integration.intellij.cli.PropertiesCommand;

import java.util.ArrayList;
import java.util.List;
import java.util.Arrays;
import java.lang.reflect.Array;

/**
 * Launches a parallels dialog that allows a user to view objects with parallels (in a non-working state).
 */
public class ShowParallelsAction extends CMAction {

    public void actionPerformed(AnActionEvent e) {
        // Get project and selected files
        VirtualFile[] selection = e.getData(DataKeys.VIRTUAL_FILE_ARRAY);
        project = e.getData(DataKeys.PROJECT);

        VirtualFile[] controlledFiles = removeInvalidFiles(selection);

        // Call ParallelsDialog if there is a selection result and it is greater than 0
        if((controlledFiles != null) && (controlledFiles.length > 0)) {
            try {
                // Call ParallelsDialog
                new ParallelsDialog(project, new ArrayList<VirtualFile>(Arrays.asList(controlledFiles)));
            } catch (VcsException exception) {
                VcsUtil.showErrorMessage(project,
                        "An error was encountered attemping to show parallels: \n" + exception.getMessage(),
                        "Warning");
            }
        }
        else {
            Messages.showMessageDialog(project, "No parallels were found for the selected object(s)", "No parallels found", null);
        }
    }

    public VirtualFile[] removeInvalidFiles(VirtualFile[] files) {
        ArrayList<VirtualFile> goodFiles = new ArrayList<VirtualFile>();

        for (VirtualFile tmp : files) {
            boolean result = new PropertiesCommand(tmp, project).isControlled();
            if(result) {
                goodFiles.add(tmp);
            }
        }

        return goodFiles.toArray(new VirtualFile[goodFiles.size()]);
    }
}
