// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.actions;

import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
//import com.intellij.openapi.actionSystem.DataConstants;
import com.intellij.openapi.actionSystem.DataKeys;
import com.intellij.openapi.project.Project;
import com.telelogic.integration.intellij.cli.Session;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

/**
 * This handles user actions for starting a GUI Synergy session
 * @author Luke Stahlman
 */
public class StartGUI extends AnAction implements ActionListener {
    private Project project;

    /**
     * Default constrcutor
     */
    public StartGUI(){ super(); }

    /**
     * Constructor with Project parameter.  Can be used to start sessions without first firing an action.
     * @param p Project
     */
    public StartGUI(Project p) {
        super();
        project = p;
    }

    /**
     * Used for the menu-based start action (Version Control -> CM -> Session GUI Session)
     * @param e Action
     */
    public void actionPerformed(AnActionEvent event) {
        project = (Project)event.getData(DataKeys.PROJECT);
        execute(project);
    }

    /**
     * Used for the button-based start action (in the CM tool window's opening view)
     * @param e Action
     */
    public void actionPerformed(ActionEvent e) {
        execute(project);
    }

    /**
     * Session the session
     * @param project Project
     */
    private static void execute(Project project) {
        Session mySession = new Session(project);
        mySession.setGUI(true);
        mySession.start();
    }
}
