// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.actions;

import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.DataKeys;
//import com.intellij.openapi.actionSystem.DataConstants;
import com.intellij.openapi.project.Project;
import com.telelogic.integration.intellij.cli.Session;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

/**
 * @author Luke Stahlman
 * Handles actions to stop the current CM session
 */

public class StopSession extends AnAction implements ActionListener {
    private Project project;

    /**
     * Default constrcutor
     */
    public StopSession() {}

    /**
     * Constructor used when adding this class as an ActionListener
     * @param p Project
     */
    public StopSession(Project p) {
        super();
        project = p;
    }

    /**
     * Action method called via an IntelliJ popup menu.  These actions contain context data.
     * @param event Action data
     */
    public void actionPerformed(AnActionEvent event) {
        project = (Project)event.getData(DataKeys.PROJECT);
        Session mySession = new Session(project);
        mySession.stop();
    }

    /**
     * Action method called via a JComponent (eg JButton).  These actions don't contain context data, so the class
     * needs to be instantiated with StopSession(Project p) before this method can be used
     * @param event Action data. Not used, but required
     */
    public void actionPerformed(ActionEvent event) {
        Session mySession = new Session(project);
        mySession.stop();
    }
}
