// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.actions;

import com.intellij.openapi.actionSystem.AnActionEvent;
//import com.intellij.openapi.actionSystem.DataContext;
//import com.intellij.openapi.actionSystem.DataConstants;
import com.intellij.openapi.actionSystem.DataKeys;
import com.intellij.openapi.project.Project;
import static com.intellij.openapi.ui.Messages.showMessageDialog;
import static com.intellij.openapi.ui.Messages.getErrorIcon;
import com.telelogic.integration.intellij.cm.CMConfiguration;
import com.telelogic.integration.intellij.cm.CMUtil;
import com.telelogic.integration.intellij.cli.UpdateCommand;

/**
 * Handles user actions related to updating the project workarea
 * @author Luke Stahlman
 */
public class UpdateAction extends CMAction {

    /**
     * Handles IDEA popup menu actions.
     * Project, config and file information is gathered from the event data.  On successful validation, the CLI command
     * is executed via com.telelogic.integration.intellij.cm.UpdateCommand.
     * @param event Event data
     */
    public void actionPerformed(AnActionEvent event) {
        project = (Project)event.getData(DataKeys.PROJECT);
        myConfig = CMConfiguration.getInstance(project);
        virtualFiles = CMUtil.getVirtualFiles( event );

        if(validateAction())
        {
            new UpdateCommand(virtualFiles[0], project);
        }
    }

    /**
     * Overloads super method for additional validation.
     * @return Whether the validation checks succeeded
     */
    private boolean validateAction() {
        // Look for a CM session
        if(!myConfig.SESSION_STARTED)
        {
            // Ask user to first start a CM Session
            showMessageDialog("No active CM session is present", "Error", getErrorIcon());
            return false;
        }
        else{
            if(virtualFiles.length > 1 || virtualFiles.length == 0 || !virtualFiles[0].isDirectory()) {
                showMessageDialog("Please select a directory to update", "Update Warning", getErrorIcon());
                return false;
            }
            else {
                return true;
            }

        }
    }
}
