// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.actions;

import com.intellij.openapi.project.Project;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.actionSystem.DataKeys;
//import com.intellij.openapi.actionSystem.DataConstants;
import com.intellij.openapi.ui.Messages;
import com.telelogic.integration.intellij.cm.CMConfiguration;
import com.telelogic.integration.intellij.cm.CMUtil;
import com.telelogic.integration.intellij.cli.UseVersionCommand;

/**
 * Handles user actions for the check in command
 * @author Luke Stahlman
 */
public class UseVersionAction extends CMAction {

    /**
     * Handles IDEA popup menu actions.
     * Project, config and file information is gathered from the event data.  On successful validation, the CLI command
     * is executed via com.telelogic.integration.intellij.cm.UseVersionCommand.
     * @param event Event data
     */
    public void actionPerformed(AnActionEvent event) {
        project = (Project)event.getData(DataKeys.PROJECT);
        myConfig = CMConfiguration.getInstance(project);
        //status = CMPlugin.getInstance(project).toolWindow;
        virtualFiles = CMUtil.getVirtualFiles( event );


        if(validateAction()) {
            new UseVersionCommand(project, virtualFiles[0]);
        }
    }

    /**
     * Overloads super method for additional validation.
     * @return Whether the validation checks succeeded
     */
    private boolean validateAction() {
        // Look for a CM session
        if(!myConfig.SESSION_STARTED)
        {
            // Ask user to first start a CM Session
            Messages.showMessageDialog("No active CM session is present", "Error", Messages.getErrorIcon());
            return false;
        }
        else{
            if(virtualFiles.length == 0){
                Messages.showMessageDialog("No files or directories were selected", "Use Version Warning",
                        Messages.getErrorIcon());
                return false;
            }
            else if (virtualFiles.length > 1) {
                Messages.showMessageDialog("Only one object can be selected for this operation", "Use Version Warning",
                        Messages.getErrorIcon());
                return false;
            }
            else {

                // Fix: Do not ask for a task, as it is not required for this operation
                return true;

                /*if(myConfig.getDefaultTask().equals("")) {
                    Messages.showMessageDialog("Please set the current task before invoking this operation",
                            "Use Version Warning", Messages.getErrorIcon());
                    return false;

                }
                else {
                    return true;
                }*/
            }

        }
    }
}
