// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.cli;

import com.intellij.openapi.project.Project;
import com.telelogic.integration.intellij.ui.CMToolWindow;
import com.telelogic.integration.intellij.cm.CMPlugin;

import javax.swing.*;
import java.util.ArrayList;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.InputStream;
import java.io.IOException;

public abstract class AbstractOutputConsumer {

    protected Project _project;
    protected CMToolWindow _tw;
    protected Process _process;
    protected boolean _sendToConsole = false;
    protected ArrayList<String> errors;
    protected boolean failed = false;

    protected AbstractOutputConsumer(Project project, Process process, boolean console, boolean redirectedErrorStream){

            _project = project;
            _tw = CMPlugin.getInstance(_project).toolWindow;
            _process = process;
            _sendToConsole = console;

            consume(_process.getInputStream());

            if(!redirectedErrorStream) {
                consume(_process.getErrorStream());
            }
        }

    protected void consume(InputStream stream) {
        ArrayList<String> result = new ArrayList<String>();
        BufferedReader reader = new BufferedReader(new InputStreamReader(stream));

        String line;
        try {
            while((line = reader.readLine()) != null) {
                result.add(line);
                findErrors(line);

                if(_sendToConsole) {
                    final String message = line;
                    SwingUtilities.invokeLater(new Runnable() {
                        public void run() {
                            _tw.appendConsole(message);
                        }
                    });
                }
            }

            finished(result);

        } catch (IOException e) {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }
    }

    protected String getSummary(ArrayList<String> result) {
        String summary = "";

        boolean atSummary = false;
        for (String line : result) {

            if (atSummary) {
                summary += line + "\n";
            } else {
                if (line.matches(".*Summary:.*")) {
                    atSummary = true;
                }
            }
        }

        return summary;
    }

    abstract protected void findErrors(String line);

    abstract protected void finished(ArrayList<String> result);
}
