// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.cli;

import com.intellij.openapi.progress.ProgressIndicator;
import com.intellij.openapi.progress.ProgressManager;

import java.util.ArrayList;

/**
 * Runnable that includes a ProgressIndicator object when available
 */
public abstract class CMRunnable implements Runnable {
    ProgressIndicator   indicator           = null;
    boolean             indicatorRunning    = false;
    ProgressManager     progressManager     = ProgressManager.getInstance();
    double              incrementer;

    public CMRunnable(double incrementer) {
        this.incrementer = incrementer;
        setUpIndicator();
    }

    public void setUpIndicator() {
        if((indicator = progressManager.getProgressIndicator()) != null) {
            indicator.setFraction(0);
            if(incrementer > 0) {
                indicator.setIndeterminate(false);
            }
            else {
                indicator.setIndeterminate(true);
            }
            if(!indicator.isRunning()) {
                indicator.start();
            }
            else {
                indicatorRunning = true;
            }
        }
    }

    public void setText(String text) {
        if(indicator != null) {
            indicator.setText(text);
        }
    }

    public void setText2(String text) {
        if(indicator != null) {
            indicator.setText2(text);
        }
    }

    public void increment() {
        if(indicator != null) {
            indicator.setFraction(indicator.getFraction() + incrementer);
        }
    }

    public void stopIndicator() {
        if(indicator != null && !indicatorRunning) {
            indicator.stop();
        }
    }
}
