// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.cli;

import com.intellij.openapi.project.Project;
import com.telelogic.integration.intellij.cm.CMExceptionHandler;

import java.util.ArrayList;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;


/**
 * Opens the UseVersion dialog and executes the "ccm use" command based on the user's choice
 * @author Luke Stahlman
 */
public class DelimiterCommand extends AbstractCommand {

    // "-" is Synergy's default delimiter.
    private String delimiter = "-";

    public DelimiterCommand(Project p) {
        super(p);
        execute();
    }

    private void execute(){
        options = new ArrayList<String>();

        options.add(myConfig.getPath());
        options.add("delim");

        String[] commands = options.toArray(new String[options.size()]);

        try {

            process = CommandHelper.runCommand(commands, myConfig.getCmEnvPath());
            delimiter = getDelim(process);

        } catch (Exception e) {

            new CMExceptionHandler(e);

        }

    }

    private String getDelim(Process process) {
        BufferedReader br = new BufferedReader(new InputStreamReader(process.getInputStream()));

        String line = "";

        try {
            while((line = br.readLine()) != null) {
                if(!line.equals(""))
                {
                    break;
                }
            }
        } catch (IOException e) {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }

        return line;
    }

    public String getResult() {
        return delimiter;
    }

    /**
     * String value of this class
     *
     * @return Name of the class
     */
    public String toString() {
        return null;  //To change body of implemented methods use File | Settings | File Templates.
    }
}
