// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.cli;

import com.intellij.openapi.project.Project;
import com.intellij.openapi.vfs.VirtualFile;
import com.telelogic.integration.intellij.cm.CMExceptionHandler;

import java.util.ArrayList;

/**
 * Implements the ccm relate command.  Used for merge operations done outside of Synergy's normal procedures.
 */
public class RelateCommand extends AbstractCommand {

    public RelateCommand(Project p) {
        super(p);
        options = new ArrayList<String>();
    }

    public void doRelate(String predecessor, String successor) {
        // ccm relate -from predecessor -to successor -name successor
        options.add(myConfig.getPath());
        options.add("relate");

        options.add("-from");
        options.add(predecessor);
        options.add("-to");
        options.add(successor);
        options.add("-name");
        options.add("successor");

        String[] commands = options.toArray(new String[options.size()]);

        try {
            toolWindow.appendConsole("Starting Relate Operation...");
            // Run command
            process = CommandHelper.runCommand(commands, myConfig.getCmEnvPath());

            new HelperThread(this).start();

        } catch (Exception e) {
            new CMExceptionHandler(e);
        }
    }

    public String toString() {
        return "Relate";
    }
}
