// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.cli;

import com.intellij.openapi.project.Project;
import com.intellij.openapi.vfs.VirtualFile;
import com.telelogic.integration.intellij.cm.CMExceptionHandler;
import java.util.ArrayList;

/**
 * This runs the Update command on part of the IDEA project.
 * @author Luke Stahlman
 */
public class UpdateCommand extends AbstractCommand {

    /**
     * Gathers environment information as well as the object to be updated
     * @param f The object to be updated
     * @param p The active IDEA project
     */
    public UpdateCommand(VirtualFile f, Project p) {
        super(p);

        toolWindow.focusOnConsole();
        update(f);

    }

    /**
     * Runs the "ccm update" command based on the object passed to it (either a file or directory)
     * @param file The file to be updated (in this case, it's a VirtualFile, which can be a directory)
     */
    private void update(VirtualFile file) {
        //Process p;
        //BufferedReader br;
        ArrayList<String> options = new ArrayList<String>();

        // build checkin command
        // ccm co -c "comment"  <file> <file> <file>...
        options.add(myConfig.getPath());
        options.add("update");
        options.add(file.getPath());

        String[] commands = options.toArray(new String[options.size()]);

        try {
            toolWindow.appendConsole("Starting Update Operation...");
            // Run command
            process = CommandHelper.runCommand(commands, myConfig.getCmEnvPath());

            //br = new BufferedReader(new InputStreamReader(p.getInputStream()));
            //new DisplayThread(messages).start();
            //new HelperThread(project, toolWindow, br, HelperThread.UPDATE).start();

            new HelperThread(this).start();

        } catch (Exception e) { new CMExceptionHandler(e); }
    }

    /**
     * @see com.telelogic.integration.intellij.cli.AbstractCommand#toString()
     */
    public String toString() { return "Update"; }
}
