// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.cli.helpers;

import com.telelogic.integration.intellij.ui.CMToolWindow;
import com.telelogic.integration.intellij.cli.Tasks;
import com.telelogic.integration.intellij.cli.DelimiterCommand;
import com.telelogic.integration.intellij.cm.CMPlugin;
import com.telelogic.integration.intellij.cm.CMConfiguration;
import com.intellij.openapi.project.Project;

/**
 * Handles session loading via a thread so the IDEA UI doesn't freeze while session data is gathered for display
 * in the tool window.
 */
public class RunStartupCommands extends Thread {
    Project         project;
    CMConfiguration config;
    String          ccmAddress;
    CMToolWindow    toolWindow;

    /**
     * Carries out misc. operations when a session is started
     * @param project The active IDEA project
     * @param ccmAddr The CCM_ADDR environment variable to be used
     */
    RunStartupCommands(Project project, String ccmAddr) {
        this.project = project;
        this.ccmAddress = ccmAddr;
        this.toolWindow = CMPlugin.getInstance(project).toolWindow;
        this.config = CMConfiguration.getInstance(project);
        this.setPriority(Thread.NORM_PRIORITY);
    }

    /**
     * Sets the current task if there is one, then invokes the tool window's sessionStarted() method.
     */
    public void run() {

        config.setCmEnvPath(ccmAddress);
        config.setCmDelim(new DelimiterCommand(project).getResult());

        if(!config.getDefaultTask().equals("")) {
            Tasks.setCurrentTask(config.getDefaultTask(), project);
        }
        CMPlugin.getInstance(project).sessionStarted();
    }
}
