// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.cm;

import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.PropertyKey;

import java.util.ResourceBundle;
import java.lang.ref.Reference;
import java.lang.ref.SoftReference;

import com.intellij.CommonBundle;

/**
 * Handles calls to the CMBundle Resource Bundle. This is useful both for consolidating strings into a single location
 * and for future localization of this plugin (if needed)
 * Created automatically by IDEA. Not all methods are known
 */
public class CMBundle {
    private static Reference<ResourceBundle> ourBundle;

    @NonNls
    private static final String BUNDLE = "com.telelogic.integration.intellij.cm.CMBundle";

    /**
     * Default constructor
     */
    private CMBundle() {
    }

    /**
     * Finds and returns the desired string in the resource bundle. This method utilizes the CommonBundle class to
     * get its data
     * @param key       The name of the string desired
     * @param params    Extra parameters to send to the CommonBundle class
     * @return          The desired string
     */
    public static String message(@PropertyKey(resourceBundle = BUNDLE)String key, Object... params) {
        return CommonBundle.message(getBundle(), key, params);
    }

    /**
     * Generated method that appears to look for the specific bundle being utilized in the plugin and returns it
     * @return The resource bundle being used
     */
    private static ResourceBundle getBundle() {
        ResourceBundle bundle = null;
        if (ourBundle != null) bundle = ourBundle.get();
        if (bundle == null) {
            bundle = ResourceBundle.getBundle(BUNDLE);
            ourBundle = new SoftReference<ResourceBundle>(bundle);
        }
        return bundle;
    }
}
