// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.cm;

import com.intellij.openapi.vcs.changes.ContentRevision;
import com.intellij.openapi.vcs.VcsException;
import com.intellij.openapi.vcs.FilePath;
import com.intellij.openapi.vcs.history.VcsRevisionNumber;
import com.intellij.openapi.project.Project;
import com.telelogic.integration.intellij.cli.AttributeCommand;
import org.jetbrains.annotations.Nullable;
import org.jetbrains.annotations.NotNull;

public class CMContentRevision implements ContentRevision {

    private Project             project;
    private FilePath            filePath;
    private VcsRevisionNumber   revision;

    public CMContentRevision (@NotNull Project project, @NotNull  FilePath path, @NotNull  VcsRevisionNumber revision) {
        this.project    = project;
        this.filePath   = path;
        this.revision   = revision;
    }

    @Nullable
    public String getContent() throws VcsException {
        // Get content for the revision of this file

        if(revision instanceof CMRevisionNumber) {
            CMRevisionNumber cmRev = (CMRevisionNumber)revision;
            byte[] fileContent = new AttributeCommand(project, cmRev.getObjectName()).getAsByte(AttributeCommand.SOURCE);
            return new String(fileContent);
        }
        else {
            return null;
        }

    }

    @NotNull
    public FilePath getFile() {
        return filePath;
    }

    @NotNull
    public VcsRevisionNumber getRevisionNumber() {
        return revision;
    }
}
