// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.cm;

import com.intellij.openapi.fileEditor.FileEditorManagerListener;
import com.intellij.openapi.fileEditor.FileEditorManager;
import com.intellij.openapi.fileEditor.FileEditorManagerEvent;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.ui.Messages;
import com.telelogic.integration.intellij.cli.PropertiesCommand;
import com.telelogic.integration.intellij.cli.CheckOutCommand;

/**
 * Handles actions fired by changes to the IDEA File Editor. This is used to determine whether any plugin-specific
 * actions should be taken based on changes in the editor.
 */
public class CMFileEditorListener implements FileEditorManagerListener {
    private Project project;
    private CMConfiguration config;

    /**
     * Main constructor
     * @param p The active IDEA project
     */
    public CMFileEditorListener(Project p) {
        super();
        project = p;
        config = CMConfiguration.getInstance(project);
    }

    /**
     * @see com.intellij.openapi.fileEditor.FileEditorManagerListener#fileClosed(com.intellij.openapi.fileEditor.FileEditorManager, com.intellij.openapi.vfs.VirtualFile)
     */
    public void fileClosed(FileEditorManager source, VirtualFile file) {}

    /**
     * @see com.intellij.openapi.fileEditor.FileEditorManagerListener#fileOpened(com.intellij.openapi.fileEditor.FileEditorManager, com.intellij.openapi.vfs.VirtualFile)
     */
    public void fileOpened(FileEditorManager source, VirtualFile file) {}

    /**
     * @see com.intellij.openapi.fileEditor.FileEditorManagerListener#selectionChanged(com.intellij.openapi.fileEditor.FileEditorManagerEvent)
     */
    public void selectionChanged(FileEditorManagerEvent e) {

        config.setSelectedFile(e.getNewFile());

        /*VirtualFile f = e.getNewFile();
        if(config.SESSION_STARTED) {
            if(f != config.getSelectedFile()) {
                config.setSelectedFile(f);
                CMPlugin.getInstance(project). toolWindow.updateCurrentFileTab(f);
            }
        }*/
    }
}
