/*
 * Copyright 2000-2006 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.cm;

import com.intellij.openapi.project.Project;
import com.intellij.openapi.vfs.*;
import com.intellij.openapi.ui.Messages;
import com.telelogic.integration.intellij.cli.PropertiesCommand;

/**
 * Listens for changes in project files. This class implements IDEA's VirtualFileListener, but for some reason it does
 * not work exactly as IDEA advertises. An instance of this class is created when an IDEA project is opened, but most
 * usages are commented out until VirtualFileListener becomes more predictable.
 *
 * Portions of this code are derived from the JetBrains VSS Integration, which is included in the IntelliJ IDEA Plugin 
 * Development Package. This package can be found at:
 * http://www.jetbrains.com/idea/plugins/plugin_developers.html
 */
class CMFileListener implements VirtualFileListener
{
    private Project myProject;
    private CMConfiguration config;

    /**
     * Main constructor
     * @param project The active IDEA project
     */
    public CMFileListener( Project project ) {
        super();
        myProject = project;
        config = CMConfiguration.getInstance(myProject);
    }

    /** @see com.intellij.openapi.vfs.VirtualFileListener#beforeContentsChange(com.intellij.openapi.vfs.VirtualFileEvent) */
    public void beforeContentsChange(VirtualFileEvent event) {

        Messages.showMessageDialog("A file is being modified","A file is being modified",null);

        VirtualFile file = event.getFile();

        // Check if file is checked out
        if(new PropertiesCommand(file, myProject).isCheckedOut()) {
            // Check if task is set
        }


        // If task is set, check out file.  If not, complain & prevent modification

    }

    /** @see com.intellij.openapi.vfs.VirtualFileListener#contentsChanged(com.intellij.openapi.vfs.VirtualFileEvent) */
    public void contentsChanged(VirtualFileEvent event) {
        Messages.showMessageDialog(myProject, "A file has been modified","A file has been modified",null);
    }

    /** @see com.intellij.openapi.vfs.VirtualFileListener#fileDeleted(com.intellij.openapi.vfs.VirtualFileEvent) */
    public void fileDeleted(VirtualFileEvent event) {}   // Delete in CM? Or notify need to reconcile?

    /** @see com.intellij.openapi.vfs.VirtualFileListener#fileMoved(com.intellij.openapi.vfs.VirtualFileMoveEvent) */
    public void fileMoved(VirtualFileMoveEvent event) {} // Refactor in CM? Or notify need to reconcile?

    /** @see com.intellij.openapi.vfs.VirtualFileListener#beforeFileMovement(com.intellij.openapi.vfs.VirtualFileMoveEvent) */
    public void beforeFileMovement(VirtualFileMoveEvent event)
    {
    }

    /** @see com.intellij.openapi.vfs.VirtualFileListener#propertyChanged(com.intellij.openapi.vfs.VirtualFilePropertyEvent) */
    public void propertyChanged(VirtualFilePropertyEvent event) {

        Messages.showMessageDialog("property changed", "", null);
    }

    /** @see com.intellij.openapi.vfs.VirtualFileListener#beforePropertyChange(com.intellij.openapi.vfs.VirtualFilePropertyEvent) */
    public void beforePropertyChange(VirtualFilePropertyEvent event)
    {

    }

    /** @see com.intellij.openapi.vfs.VirtualFileListener#fileCreated(com.intellij.openapi.vfs.VirtualFileEvent) */
    public void fileCreated(VirtualFileEvent event)
    {
        Messages.showMessageDialog("file created", "file created", null);

        //VirtualFile file = event.getFile();

        // Check options. Automatically add if "auto" was selected.  Otherwise, prompt to add.
        if(config.getOptionTabAdd().equals("auto")) {
            // Add now
            //new AddCommand(file, myProject);
        }
        else {
            //If yes (response value = 0), add file to synergy, then check out
            int response = Messages.showYesNoDialog(myProject, "Would you like this new file added to Synergy?","Add to Synergy",null);
            if(response == 0) {
                // Add to Synergy
                // Check for session.  Session if not
                // Check out directory?
                // Add file
                //new AddCommand(file, myProject);
            }
        }
    }

    /** @see com.intellij.openapi.vfs.VirtualFileListener#beforeFileDeletion(com.intellij.openapi.vfs.VirtualFileEvent) */
    public void beforeFileDeletion(VirtualFileEvent event)
    {

    }

    /**
     * IDEA 7.0 compatibility
     * @param event
     */
    public void fileCopied(VirtualFileCopyEvent event) {
        //To change body of implemented methods use File | Settings | File Templates.
    }
}
