// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.cm;

import com.intellij.openapi.vcs.history.VcsFileRevision;
import com.intellij.openapi.vcs.history.VcsRevisionNumber;
import com.intellij.openapi.vcs.VcsException;
import com.intellij.openapi.vcs.FilePath;
import com.telelogic.integration.intellij.cli.History;

import java.util.Date;
import java.io.IOException;

/**
 * Synergy implementation of VcsFileRevision
 */
public class CMFileRevision implements VcsFileRevision {
    private History.HistoryObject   data;
    private FilePath                path;
    private String                  objectName;

    public CMFileRevision(History.HistoryObject data, FilePath path) {
        this.data = data;
        this.path = path;
    }

    public CMFileRevision(History.HistoryObject data, String objectName) {
        this.data = data;
        this.objectName = objectName;
    }

    // Object version
    public VcsRevisionNumber getRevisionNumber() {
        return CMRevisionNumber.getInstance(data);
    }

    // Synergy deals with releases, components, platforms and subsystems instead of "branches".  In this method, the
    // release attribute will be used
    public String getBranchName() {
        return data.getRelease();
    }

    // Date/Time checked in
    public Date getRevisionDate() {
        // Returns modified date, which is more accurate than the creation date in this case
        //return data.getMofidied();
        return data.getModifiedDate();
        //return null;
    }

    //  Owner
    public String getAuthor() {
        return data.getOwner();
    }

    // Checkin comment
    public String getCommitMessage() {
        return data.getComment();
    }

    public void loadContent() throws VcsException {
        data.loadSource();
    }

    // Return a byte array of the file
    public byte[] getContent() throws IOException {
        return data.getSource();
    }

    public History.HistoryObject getHistoryData() {
        return data;
    }
}
