// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.cm;

import com.intellij.openapi.vcs.history.*;
import com.intellij.openapi.vcs.FilePath;
import com.intellij.openapi.vcs.VcsException;
import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.util.ui.ColumnInfo;
import com.telelogic.integration.intellij.cli.History;
import com.telelogic.integration.intellij.cli.AttributeCommand;
import com.telelogic.integration.intellij.actions.MergeAction;
import org.jetbrains.annotations.NonNls;

import java.util.*;
import java.lang.reflect.Array;

/**
 * Implements VcsHistoryProvider to integrate with IDEA's history/diff functionality
 */
public class CMHistoryProvider implements VcsHistoryProvider {

    private Project project;
    private CMPlugin cmPlugin;

    public CMHistoryProvider(CMPlugin vcs) {
        cmPlugin = vcs;
        project = vcs.getProject();
    }

    public CMHistoryProvider(Project project) {
        this.project = project;
        cmPlugin = CMPlugin.getInstance(project);
    }

    @NonNls
    public String getHelpId() {
        return null;
    }

    public HistoryAsTreeProvider getTreeHistoryProvider() {
        return null;
    }

    public ColumnInfo[] getRevisionColumns() {
        ArrayList<ColumnInfo> columns = new ArrayList<ColumnInfo>();
        //columns.add(new ColumnInfo.StringColumn("Task"));
        //return columns.toArray(new ColumnInfo[columns.size()]);

        /*final ColumnInfo<VcsFileRevision, String> task = new ColumnInfo<VcsFileRevision, String>("Task") {
            public String valueOf(VcsFileRevision revision) {
                 if(revision instanceof CMFileRevision) {

                     String task = ((CMFileRevision)revision).getHistoryData().getTask();
                     if(task != null) {
                         return task;
                     }
                 }

                return "";
            }
        };

        final ColumnInfo<VcsFileRevision, String> lastModified = new ColumnInfo<VcsFileRevision, String>("Last Modified") {
             public String valueOf(VcsFileRevision revision) {

                 if(revision instanceof CMFileRevision) {
                     //Date revDate = ((CMFileRevision)revision).getRevisionDate();
                     String revDate = ((CMFileRevision)revision).getHistoryData().getMofidied();
                     if(revDate != null) {
                         return revDate;
                     }
                 }

                return "";
             }
        };

      final ColumnInfo<VcsFileRevision, String> created = new ColumnInfo<VcsFileRevision, String>("Created") {
             public String valueOf(VcsFileRevision revision) {

                 if(revision instanceof CMFileRevision) {
                     String revDate = ((CMFileRevision)revision).getHistoryData().getCreated();
                     if(revDate != null) {
                         return revDate;
                     }
                 }

                return "";
             }
        };

        columns.add(task);*/
        //columns.add(created);
        //columns.add(lastModified);

        //final ColumnInfo<VcsFileRevision, String>[] array = (ColumnInfo<VcsFileRevision, String>[]) Array.newInstance(myColumnInfo.getClass(), 1);
		//array[0] = myColumnInfo;

        return columns.toArray(ColumnInfo.EMPTY_ARRAY);

        //return array;
    }

    public AnAction[] getAdditionalActions(FileHistoryPanel fileHistoryPanel) {
        //return new AnAction[]{new MergeAction()};
        return new AnAction[0];
    }

    /**
     * 
     * @param filePath
     * @return
     * @throws VcsException
     */
    public VcsHistorySession createSessionFor(final FilePath filePath) throws VcsException {
        LinkedHashMap<History.HistoryObject.Key, History.HistoryObject> historyData;     
        ArrayList<VcsFileRevision> revisions = new ArrayList<VcsFileRevision>();

        // Get revision info
        historyData = History.getRevisionData(project, filePath);

        for(Map.Entry<History.HistoryObject.Key, History.HistoryObject> entry : historyData.entrySet())
        {
            revisions.add(new CMFileRevision(entry.getValue(), filePath));
        }

        // If there's nothing, return null
        if(revisions == null) {
            return null;
        }
        /*
        final FilePath committedPath = ChangesUtil.getCommittedPath(myVcs.getProject(), filePath);
        final List<VcsFileRevision> revisions = getRevisionsList(committedPath);
        if (revisions == null) {
          return null;
        }
        return new VcsHistorySession(revisions) {
          @Nullable
          public VcsRevisionNumber calcCurrentRevisionNumber() {
            return getCurrentRevision(committedPath);
          }

         */

        return new VcsHistorySession(revisions) {

            private VcsRevisionNumber currentRevision = null;

            public VcsRevisionNumber calcCurrentRevisionNumber() {
                if(currentRevision == null) {
                    currentRevision =  new CMRevisionNumber(new AttributeCommand(project, filePath).get(AttributeCommand.VERSION));
                }

                return currentRevision;
            }

            public boolean isContentAvailable(final VcsFileRevision revision) {
                return true;
            }

            public boolean allowAsyncRefresh() {
                return true;
            }

            // Disable auto refresh of the history view
            public boolean refresh() {
                return false;
            }

            public boolean isCurrentRevision(VcsRevisionNumber vcsRevisionNumber) {
                if(vcsRevisionNumber instanceof CMRevisionNumber) {
                    CMRevisionNumber rev = (CMRevisionNumber)vcsRevisionNumber;

                    CMRevisionNumber currentRevision = (CMRevisionNumber)calcCurrentRevisionNumber();

                    return (rev.getVersion().compareTo(currentRevision.getVersion()) == 0);
                }
                else {
                    return super.isCurrentRevision(vcsRevisionNumber);    //To change body of overridden methods use File | Settings | File Templates.
                }
            }
        };
    }

    /**
     * IDEA 7.0 compatibility
     * @return Whether IDEA's own date format should be displayed in the revision history UI
     */
    public boolean isDateOmittable() {
        return false;  //To change body of implemented methods use File | Settings | File Templates.
    }
}
