// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.cm;

import com.intellij.openapi.vcs.history.VcsRevisionNumber;
import com.telelogic.integration.intellij.cli.History;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Stack;
import java.lang.reflect.Array;

public class CMRevisionNumber implements VcsRevisionNumber {

    History.HistoryObject objectInfo;
    CMFileRevision data;
    String version;
    String objectName;

    public CMRevisionNumber(String revisionNumber) {
        version = revisionNumber;
    }

    public CMRevisionNumber(String revisionNumber, String objectName) {
        version         = revisionNumber;
        this.objectName = objectName;
    }

    /*
    public CMRevisionNumber(History.HistoryObject objectInfo) {
        this.objectInfo = objectInfo;
    } */

    public String asString() {
        //return objectInfo.getVersion();
        return version;
    }

    public String getObjectName() {
        return objectName;   
    }

    public History.HistoryObject getHistoryObject() {
        return objectInfo;
    }

    public String getVersion() {
        return version;
    }

    public static CMRevisionNumber getInstance(History.HistoryObject objectInfo) {
        //return new CMRevisionNumber(objectInfo);
        return new CMRevisionNumber(objectInfo.getVersion(), objectInfo.getObjectName());
    }

    /**
     *
     * @param vcsRevisionNumber
     * @return
     */
    public int compareTo(VcsRevisionNumber vcsRevisionNumber) {

        // Compare using the version numbers
        // Assumes versions are in format 1.01.20.30.6.2....
        if(vcsRevisionNumber instanceof CMRevisionNumber) {

            CMRevisionNumber comparedRevision = (CMRevisionNumber)vcsRevisionNumber;

            String[] versionOneTokens = this.getVersionArray();
            String[] versionTwoTokens = comparedRevision.getVersionArray();

            if(versionOneTokens == null) {
                return -1;
            }
            else if(versionTwoTokens == null) {
                return 1;
            }
            else {

                for(int i = 0; i < versionOneTokens.length; i++) {

                    // If versionTwoTokens has run out of values, then it has a lower version value
                    if(i >= versionTwoTokens.length) {
                        return 1;
                    }

                    try {

                        int verionOneInt = Integer.parseInt(versionOneTokens[i]);
                        int verionTwoInt = Integer.parseInt(versionTwoTokens[i]);

                        // If these tokens don't match, then a result can be returned
                        // Otherwise, the next token is evaluated
                        if (verionOneInt > verionTwoInt) {
                            return 1;
                        } else if (verionOneInt < verionTwoInt) {
                            return -1;
                        }
                    }
                    catch (NumberFormatException e) {
                        return -1;
                    }
                }

            }
        }

        // Default return if the versions aren't comparable
        return -1;

    }

    private String[] getVersionArray() {

        String[] tokens = null;

        // Split version into tokens: 10.4.1 -> {10,4,1}
        tokens = this.getVersion().split("\\.");

        // If one token is found, either the version is an integer or has been given a custom name
        // If it is an integer, place the version into the tokens array
        if(tokens.length == 1) {
            try {
                int versionInt = Integer.parseInt(this.getVersion());

                tokens = new String[]{this.getVersion()};
            }
            catch (NumberFormatException e) {
                // Integer parsing failed.  This means the version has a custom name
                // In this case, the tokens should be nullified
                tokens = null;
            }
        }

        return tokens;
    }
}
