// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.ui;

import com.intellij.openapi.ui.Messages;

import javax.swing.*;

/**
 * Handles the display of message dialogs. The main purpose is to simplify the plugin code so there aren't as many
 * blocks of code dealing solely with SwingUtilities.invokeLater
 */
public class CMMessages {
    //TODO: start using this class in the project
    /**
     * Displays a general (default) message dialog based on a string value passed to it.
     * @param msg The message to be displayed
     */
    public static void generalMessage(String msg) {
        final String message = msg;
        SwingUtilities.invokeLater(new Runnable() {
            /**
             * Show the message
             */
            public void run() {
                Messages.showMessageDialog(message, "Synergy", Messages.getInformationIcon());
            }
        });
    }

    /**
     * Displays a message dialog based on the message and title strings passed to it.
     * @param msg The message to be displayed
     * @param t   The message title
     */
    public static void generalMessage(String msg, String t) {
        final String    message = msg;
        final String    title   = t;

        SwingUtilities.invokeLater(new Runnable() {
            /**
             * Show the message
             */
            public void run() {
                Messages.showMessageDialog(message, title, Messages.getInformationIcon());
            }
        });
    }

    /**
     * Displays a message dialog based the message and title strings along with the icon passed to it.
     * @param msg The message to be displayed
     * @param t   The message title
     * @param i   The icon to be displayed in the message
     */
    public static void generalMessage(String msg, String t, Icon i) {
        final String    message = msg;
        final String    title   = t;
        final Icon      icon    = i;

        SwingUtilities.invokeLater(new Runnable() {
            /**
             * Show the message
             */
            public void run() {
                Messages.showMessageDialog(message, title, icon);
            }
        });
    }
}
