// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.ui.dialogs;

import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.openapi.vcs.merge.MergeProvider;
import com.intellij.openapi.ui.Messages;
import com.telelogic.integration.intellij.cli.History;
import com.telelogic.integration.intellij.cm.CMMergeProvider;

import javax.swing.*;
import javax.swing.table.DefaultTableModel;
import java.awt.event.*;
import java.awt.*;
import java.util.Vector;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.LinkedList;

public class MergeCandidates extends JDialog {
    private JPanel contentPane;
    private JButton buttonOK;
    private JButton buttonCancel;
    private JTable mergeTable;

    public String selection;

    public MergeCandidates(VirtualFile file, LinkedList<History.HistoryObject> candidates, LinkedHashMap<History.HistoryObject.Key, History.HistoryObject> fileData) {
        //Set up dialog
        setUpListeners();
        setContentPane(contentPane);
        setModal(true);
        setTitle("Merge candidates for " + file.getName());
        getRootPane().setDefaultButton(buttonOK);

        // Get table data
        DefaultTableModel tableModel = ObjectHistoryTableModel.getHistoryTableModel(candidates);

        // Set up table view
        mergeTable.setShowVerticalLines(true);
        mergeTable.setModel(tableModel);
        mergeTable.setShowVerticalLines(false);
        mergeTable.setColumnSelectionAllowed(false);
        mergeTable.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        mergeTable.setIntercellSpacing(new Dimension(2,0));
    }

    private void onOK() {
        int selectedRow;
        // Check if a selection was made
        if((selectedRow = mergeTable.getSelectedRow()) != -1) {
            selection = mergeTable.getValueAt(selectedRow, 0).toString();
            dispose();
        }
        else {
            Messages.showInfoMessage("Please select a file to use in the merge operation", "No file selected");
        }
    }

    private void onCancel() {
        dispose();
    }

    public static String getSelection(VirtualFile file, LinkedList<History.HistoryObject> candidates, LinkedHashMap<History.HistoryObject.Key, History.HistoryObject> fileData) {
        MergeCandidates dialog = new MergeCandidates(file, candidates, fileData);
        dialog.pack();
        dialog.setVisible(true);
        return dialog.selection;
    }

    private void setUpListeners() {

        buttonOK.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                onOK();
            }
        });

        buttonCancel.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                onCancel();
            }
        });

// call onCancel() when cross is clicked
        setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                onCancel();
            }
        });

// call onCancel() on ESCAPE
        contentPane.registerKeyboardAction(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                onCancel();
            }
        }, KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0), JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
    }

}
