// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.ui.dialogs;

import com.telelogic.integration.intellij.cli.Tasks;
import com.telelogic.integration.intellij.ui.tabs.MyTasks;
import com.intellij.openapi.project.Project;

import javax.swing.*;
import java.awt.event.*;
import java.awt.*;
import java.util.HashMap;

/**
 * Gathers and displays information about a task
 */
public class TaskPropertiesDialog extends JDialog {
    private JPanel contentPane;
    private JTabbedPane tabbedPane1;
    private JTextArea synopsis;
    private JTextField release;
    private JTextField priority;
    private JTextField subsystem;
    private JTextField platform;
    private JTextField resolver;
    private JTextArea description;
    private JTextField state;
    private JButton okButton;
    private JTextField associatedCR;
    private JButton setAsCurrentTaskButton;
    private String task;
    private Project myProject;
    private MyTasks tabController;
    //private TabsPanel tabController;

    private static int SCREENWIDTH = 350;
    private static int SCREENHEIGHT = 350;

    /*public TaskPropertiesDialog(Project project, TabsPanel controller, int taskID) {
        task = taskID;
        tabController = controller;
        myProject = project;

        setContentPane(contentPane);
        setModal(true);
        getRootPane().setDefaultButton(okButton);

        Toolkit tk = Toolkit.getDefaultToolkit();
        Dimension screenSize = tk.getScreenSize();
        int x = (screenSize.width -  SCREENWIDTH ) / 2;
        int y = (screenSize.height - SCREENHEIGHT) / 2;

        setLocation(x,y);

        synopsis.setBackground(Color.WHITE);

        okButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                onOK();
            }
        });

        setAsCurrentTaskButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                tabController.setTask();
                setAsCurrentTaskButton.setEnabled(false);
            }
        });

// call onCancel() when cross is clicked
        setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                onCancel();
            }
        });

// call onCancel() on ESCAPE
        contentPane.registerKeyboardAction(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                onCancel();
            }
        }, KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0), JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
    }*/

    /**
     * Main constructor
     * @param project The active IDEA project
     * @param controller The My Tasks tab panel
     * @param taskID The task for which properties are to be shown
     */
    public TaskPropertiesDialog(Project project, MyTasks controller, String taskID) {
        task = taskID;
        tabController = controller;
        myProject = project;

        setContentPane(contentPane);
        setModal(true);
        getRootPane().setDefaultButton(okButton);

        Toolkit tk = Toolkit.getDefaultToolkit();
        Dimension screenSize = tk.getScreenSize();
        int x = (screenSize.width -  SCREENWIDTH ) / 2;
        int y = (screenSize.height - SCREENHEIGHT) / 2;

        setLocation(x,y);

        synopsis.setBackground(Color.WHITE);

        okButton.addActionListener(new ActionListener() {
            /** @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent) */
            public void actionPerformed(ActionEvent e) {
                onOK();
            }
        });

        setAsCurrentTaskButton.addActionListener(new ActionListener() {
            /** @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent) */
            public void actionPerformed(ActionEvent e) {
                tabController.setTask();
                setAsCurrentTaskButton.setEnabled(false);
            }
        });

// call onCancel() when cross is clicked
        setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        addWindowListener(new WindowAdapter() {
            /** @see java.awt.event.WindowAdapter#windowClosing(java.awt.event.WindowEvent) */
            public void windowClosing(WindowEvent e) {
                onCancel();
            }
        });

// call onCancel() on ESCAPE
        contentPane.registerKeyboardAction(new ActionListener() {
            /** @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent) */
            public void actionPerformed(ActionEvent e) {
                onCancel();
            }
        }, KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0), JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
    }

    /**
     * Closes the dialog
     */
    private void onOK() {
        dispose();
    }

    /**
     * Closes the dialog
     */
    private void onCancel() {
        dispose();
    }

    /*
    public static void main(String[] args) {
        TaskPropertiesDialog dialog = new TaskPropertiesDialog();
        dialog.pack();
        dialog.setVisible(true);
        System.exit(0);
    } */

    /**
     * Displays the dialog
     */
    public void showDialog() {

        HashMap<String, String> properties = Tasks.getTaskProperties(myProject, task);

        setTitle("Properties for task " + task);
        synopsis.setText(properties.get("Synopsis"));
        state.setText(properties.get("State"));
        resolver.setText(properties.get("Resolver"));
        release.setText(properties.get("Release"));
        priority.setText(properties.get("Priority"));
        subsystem.setText(properties.get("Subsystem"));
        platform.setText(properties.get("Platform"));
        description.setText(properties.get("Description"));
        associatedCR.setText(properties.get("CR"));

        if(properties.containsKey("default")){
            if(properties.get("default").equals("true")) {
                setAsCurrentTaskButton.setEnabled(false);
            }
        }
        else {
            setAsCurrentTaskButton.setEnabled(true);
        }

        pack();
        setVisible(true);
    }
}
