// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.ui.tabs;

import com.telelogic.integration.intellij.cli.Tasks;
import com.intellij.openapi.project.Project;

import javax.swing.*;
import java.util.HashMap;
import java.awt.*;

/**
 * Provides the Current Task tab and its related functions
 */
public class CurrentTask {
    private JTextField  taskIDField;
    private JTextField  releaseField;
    private JTextField  associatedCRField;
    private JTextField  synopsisField;
    private JTextArea   descriptionField;
    private JTextField  priorityField;
    private JPanel      currentTask;
    private Project     project;

    /**
     * Main constructor
     * @param project The active IDEA project
     */
    public CurrentTask(Project project) {
        this.project = project;

        descriptionField.setEditable(false);
        descriptionField.setBackground(Color.WHITE);
        descriptionField.setMargin(new Insets(3,3,3,3));
        descriptionField.setBorder(BorderFactory.createEmptyBorder(2,2,2,2));

        associatedCRField.setBackground(Color.WHITE);
        taskIDField.setBackground(Color.WHITE);
        priorityField.setBackground(Color.WHITE);
        releaseField.setBackground(Color.WHITE);
        synopsisField.setBackground(Color.WHITE);
    }

    /**
     * Gets the JPanel for the Current Task tab
     * @return This class's JPanel
     */
    public JPanel getPanel() {
       return currentTask; 
    }

    /**
     * Updates the properties of the current task displayed in the JPanel
     */
    public void update() {
        new Populate().start();
    }

    /**
     * Executes and processes the commands required to gather information about the current task, then updates the
     * JPanel with that information
     */
    private class Populate extends Thread {

        /**
         * Execute and process the commands, then update the JPanel
         */
        public void run() {
            HashMap<String,String> properties = new HashMap<String,String>();

            String currentTask = Tasks.getCurrentTaskID(project);

            // If there is no current task, there's no need to display task information
            if(!currentTask.equals("")) {
                properties = Tasks.getTaskProperties(project, currentTask);

                if(properties.containsKey("Task"))          { taskIDField.setText(properties.get("Task")); }
                if(properties.containsKey("Release"))       { releaseField.setText(properties.get("Release")); }
                if(properties.containsKey("Priority"))      { priorityField.setText(properties.get("Priority")); }
                if(properties.containsKey("CR"))            { associatedCRField.setText(properties.get("CR")); }
                if(properties.containsKey("Synopsis"))      { synopsisField.setText(properties.get("Synopsis")); }
                if(properties.containsKey("Description"))   { descriptionField.setText(properties.get("Description")); }
            }
            else {
                taskIDField.setText(properties.get(""));
                releaseField.setText(properties.get(""));
                priorityField.setText(properties.get(""));
                associatedCRField.setText(properties.get(""));
                synopsisField.setText(properties.get(""));
                descriptionField.setText(properties.get(""));
            }
        }
    }
}
