// Copyright 2006, 2007 Telelogic AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.telelogic.integration.intellij.ui.tabs;

import com.intellij.openapi.project.Project;
import com.telelogic.integration.intellij.cm.CMConfiguration;
import com.telelogic.integration.intellij.actions.OptionsTabAction;

import javax.swing.*;

/**
 * Provides the Options tab and its related functions
 */
public class Options {
    private JRadioButton addAutoButton;
    private JRadioButton taskOpenPropertiesButton;
    private JRadioButton taskSetDefaultButton;
    private JRadioButton addPromptButton;
    private JPanel options;

    //private Project project;
    private CMConfiguration config;

    /**
     * Main constructor
     * @param project The active IDEA project
     */
    public Options(Project project) {
        //this.project = project;
        this.config = CMConfiguration.getInstance(project);

        // Add listeners for the Options tab panel buttons
        //OptionsTabAction coGroupAction      = new OptionsTabAction(OptionsTabAction.CHECKOUT, project);
        OptionsTabAction addGroupAction     = new OptionsTabAction(OptionsTabAction.ADD, project);
        OptionsTabAction taskGroupAction    = new OptionsTabAction(OptionsTabAction.TASK, project);

        addAutoButton.addActionListener(addGroupAction);
        addPromptButton.addActionListener(addGroupAction);
        //addManualButton.addActionListener(addGroupAction);

        taskSetDefaultButton.addActionListener(taskGroupAction);
        taskOpenPropertiesButton.addActionListener(taskGroupAction);
    }

    /**
     * Returns the JPanel for the Options tab
     * @return This class's JPanel
     */
    public JPanel getPanel() {
        return options;
    }

    /**
     * Loads the options stored in the plugin's configuration, then sets the radio button selections to match those
     * stored options
     */
    public void restoreSavedOptions() {
        // For each button group, figure out which button should be selected
       /*String addOption        = myConfig.getOption("ADD");
        String checkoutOption   = myConfig.getOption("CHECKOUT");
        String taskOption       = myConfig.getOption("TASK"); */

        String addOption =      config.getOptionTabAdd();
        //String checkoutOption = config.getOptionTabCheckout();
        String taskOption =     config.getOptionTabTask();

        if(addOption != null) {
            if(addAutoButton.getActionCommand().equals(addOption)) {
                addAutoButton.setSelected(true);
            }
            //else if(addManualButton.getActionCommand().equals(addOption)) {
            //    addManualButton.setSelected(true);
            //}
            else if(addPromptButton.getActionCommand().equals(addOption)) {
                addPromptButton.setSelected(true);
            }
        }
       /*
        if(checkoutOption != null) {

            if(checkoutOpenedButton.getActionCommand().equals(checkoutOption)) {
                checkoutOpenedButton.setSelected(true);
            }
            //else if(checkoutSaveButton.getActionCommand().equals(checkoutOption)) {
            //    checkoutSaveButton.setSelected(true);
            //}
            else if(checkoutModifiedButton.getActionCommand().equals(checkoutOption)) {
                checkoutModifiedButton.setSelected(true);
            }
            //else if(checkoutManualButton.getActionCommand().equals(checkoutOption)) {
            //    checkoutManualButton.setSelected(true);
            //}
        }
        */
        if(taskOption != null) {
            if(taskOpenPropertiesButton.getActionCommand().equals(taskOption)) {
                taskOpenPropertiesButton.setSelected(true);
            }
            else if(taskSetDefaultButton.getActionCommand().equals(taskOption)) {
                taskSetDefaultButton.setSelected(true);
            }
        }
    }
}
